=================
Who is using Neo?
=================

.. note:: This page has not yet been written.
          It will highlight some of the projects that are using Neo,
          such as Elephant_, ephyviewer_, PyNN_,
          Neurotic_, SpikeInterface_, MEArec_, tridesclous_,
          uncertainpy_ and eFEL_.

.. note:: We also plan to maintain a list of publications that mention use of Neo and/or cite the Neo article.
          For now, you can view mentions on SciCrunch_ and on `Google Scholar`_,
          and read `comments from Neo users`_ from the INCF review of Neo as a community standard.


.. _Elephant: https://github.com/NeuralEnsemble/elephant
.. _ephyviewer: https://github.com/NeuralEnsemble/ephyviewer
.. _PyNN: https://github.com/NeuralEnsemble/PyNN
.. _Neurotic: https://github.com/jpgill86/neurotic
.. _SpikeInterface: https://github.com/SpikeInterface
.. _MEArec: https://github.com/alejoe91/MEArec
.. _tridesclous: https://github.com/tridesclous/tridesclous
.. _uncertainpy: https://github.com/simetenn/uncertainpy
.. _eFEL: https://github.com/BlueBrain/eFEL
.. _SciCrunch: https://scicrunch.org/resolver/SCR_000634/mentions?q=&i=rrid:scr_000634
.. _`Google Scholar`: https://scholar.google.com/scholar?hl=en&as_sdt=0%2C5&q=%22RRID%3ASCR_000634%22+OR+%22SCR_000634%22+OR+%22neuralensemble.org%2Fneo%2F%22+OR+%22github.com%2FNeuralEnsemble%2Fpython-neo%22&btnG=
.. _`comments from Neo users`: https://f1000research.com/documents/11-658
